==> segment-wrapper-3.43.0-beta.0.tgz: package/lib/segmentWrapper.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
// @ts-check
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getConfig } from './config.js';
import { getGoogleClientID, getGoogleSessionID, setGoogleConsentMode } from './googleRepository.js';
import { checkGdprIsAccepted, getGdprPrivacyValue } from './tcf.js';
import { getXandrId } from './xandrRepository.js';
/* Default properties to be sent on all trackings */

var DEFAULT_PROPERTIES = {
  platform: 'web'
};
/* Disabled integrations when no GDPR Privacy Value is true */

export var INTEGRATIONS_WHEN_NO_CONSENTS = {
  All: false
};
/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */

export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};
/**
 * Get all needed integrations depending on the gdprPrivacy value.
 * One of them is the AdobeMarketingCloudVisitorId for Adobe Analytics integration.
 * @param {string} gdprPrivacyValue Tell if user has consents to be tracked
 * @returns {Promise<object>} Integrations that we need to use on the track
 */

var getTrackIntegrations = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(gdprPrivacyValue) {
    var isGdprAccepted, marketingCloudVisitorId, clientId, sessionId, _yield$Promise$all, adobeAnalyticsIntegration, googleAnalyticsIntegration, restOfIntegrations;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            isGdprAccepted = checkGdprIsAccepted(gdprPrivacyValue);
            marketingCloudVisitorId = null;
            clientId = null;
            sessionId = null;

            if (!isGdprAccepted) {
              _context.next = 12;
              break;
            }

            ;
            _context.next = 8;
            return Promise.all([getAdobeMCVisitorID(), getGoogleClientID(), getGoogleSessionID()]);

          case 8:
            _yield$Promise$all = _context.sent;
            marketingCloudVisitorId = _yield$Promise$all[0];
            clientId = _yield$Promise$all[1];
            sessionId = _yield$Promise$all[2];

          case 12:
            adobeAnalyticsIntegration = marketingCloudVisitorId ? {
              marketingCloudVisitorId: marketingCloudVisitorId
            } : true;
            googleAnalyticsIntegration = clientId ? {
              clientId: clientId,
              sessionId: sessionId
            } : true;
            if (clientId) setGoogleConsentMode(isGdprAccepted);
            restOfIntegrations = isGdprAccepted ? {} : INTEGRATIONS_WHEN_NO_CONSENTS; // if we don't have the user consents we remove all the integrations but Adobe Analytics

            return _context.abrupt("return", _extends({}, restOfIntegrations, {
              'Adobe Analytics': adobeAnalyticsIntegration,
              'Google Analytics': googleAnalyticsIntegration,
              'Amazon Lambda': true
            }));

          case 17:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function getTrackIntegrations(_x) {
    return _ref.apply(this, arguments);
  };
}();
/**
 * It returns externalIds to add to context
 *
 * @param {Object} param
 * @param {Object} param.context previous context
 * @param {String} param.xandrId xandrId to be included
 * @returns
 */


var getExternalIds = function getExternalIds(_ref2) {
  var context = _ref2.context,
      xandrId = _ref2.xandrId;
  var shouldSendXandrId = getConfig('sendXandrId') !== false;
  var isValidXandrId = xandrId && parseInt(xandrId) !== 0;

  if (!shouldSendXandrId || !isValidXandrId) {
    return {};
  }

  var SEGMENT_COLLECTION = 'users';
  var SEGMENT_ENCODING = 'none';
  var SEGMENT_TYPE = 'xandr_id';
  var externalIds = [].concat((context == null ? void 0 : context.externalIds) || [], [{
    collection: SEGMENT_COLLECTION,
    encoding: SEGMENT_ENCODING,
    id: xandrId,
    type: SEGMENT_TYPE
  }]);
  var uniqueExternalIds = externalIds.filter(function (_ref3, index) {
    var idFilter = _ref3.id,
        typeFilter = _ref3.type;
    return index === externalIds.findIndex(function (_ref4) {
      var idFind = _ref4.id,
          typeFind = _ref4.type;
      return idFilter === idFind && typeFilter === typeFind;
    });
  });
  return {
    externalIds: uniqueExternalIds
  };
};
/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */


export var decorateContextWithNeededData = /*#__PURE__*/function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(context) {
    var gdprPrivacyValue, isGdprAccepted, _yield$Promise$all2, integrations, xandrId;

    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (context === void 0) {
              context = {};
            }

            _context2.next = 3;
            return getGdprPrivacyValue();

          case 3:
            gdprPrivacyValue = _context2.sent;
            isGdprAccepted = checkGdprIsAccepted(gdprPrivacyValue);
            _context2.next = 7;
            return Promise.all([getTrackIntegrations(gdprPrivacyValue), getXandrId()]);

          case 7:
            _yield$Promise$all2 = _context2.sent;
            integrations = _yield$Promise$all2[0];
            xandrId = _yield$Promise$all2[1];
            return _context2.abrupt("return", _extends({}, context, !isGdprAccepted && {
              ip: '0.0.0.0'
            }, getExternalIds({
              context: context,
              xandrId: xandrId
            }), {
              gdpr_privacy: gdprPrivacyValue,
              integrations: _extends({}, context.integrations, integrations)
            }));

          case 11:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function decorateContextWithNeededData(_x2) {
    return _ref5.apply(this, arguments);
  };
}();
/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */

var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  return new Promise(function (resolve) {
    var initTrack = /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
        var newContext, newProperties, newCallback;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                _context4.next = 2;
                return decorateContextWithNeededData(context);

              case 2:
                newContext = _context4.sent;

                /**
                 * @deprecated Now we use `defaultContextProperties` middleware
                 * and put the info on the context object
                 */
                newProperties = _extends({}, getDefaultProperties(), properties);

                newCallback = /*#__PURE__*/function () {
                  var _ref7 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
                    var _yield$Promise$all3,
                        gdprPrivacyValue,
                        _args3 = arguments;

                    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
                      while (1) {
                        switch (_context3.prev = _context3.next) {
                          case 0:
                            if (callback) callback.apply(void 0, _args3); // eslint-disable-line n/no-callback-literal

                            _context3.next = 3;
                            return Promise.all([getGdprPrivacyValue()]);

                          case 3:
                            _yield$Promise$all3 = _context3.sent;
                            gdprPrivacyValue = _yield$Promise$all3[0];

                            if (checkGdprIsAccepted(gdprPrivacyValue)) {
                              resolve.apply(void 0, _args3);
                            } else {
                              resolve();
                            }

                          case 6:
                          case "end":
                            return _context3.stop();
                        }
                      }
                    }, _callee3);
                  }));

                  return function newCallback() {
                    return _ref7.apply(this, arguments);
                  };
                }();

                window.analytics.track(event, newProperties, _extends({}, newContext, {
                  context: {
                    integrations: _extends({}, newContext.integrations)
                  }
                }), newCallback);

              case 6:
              case "end":
                return _context4.stop();
            }
          }
        }, _callee4);
      }));

      return function initTrack() {
        return _ref6.apply(this, arguments);
      };
    }();

    initTrack();
  });
};
/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var identify = function identify(userId, traits, options, callback) {
  return Promise.resolve(window.analytics.identify(userId, traits, options, callback));
};
/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * @param {string} event The name of the event you’re tracking
 * @param {object=} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  // we put a flag on context to know this track is a page
  context.isPageTrack = true; // just call track again but the with the proper context

  return track(event, properties, context, callback);
};
/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */


var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};

export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};

==> segment-wrapper-3.44.0-beta.0.tgz: package/lib/segmentWrapper.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
// @ts-check
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getConfig } from './config.js';
import { checkGdprIsAccepted, getGdprPrivacyValue } from './tcf.js';
import { getXandrId } from './xandrRepository.js';
/* Default properties to be sent on all trackings */

var DEFAULT_PROPERTIES = {
  platform: 'web'
};
/* Disabled integrations when no GDPR Privacy Value is true */

export var INTEGRATIONS_WHEN_NO_CONSENTS = {
  All: false
};
/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */

export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};
/**
 * Get all needed integrations depending on the gdprPrivacy value.
 * One of them is the AdobeMarketingCloudVisitorId for Adobe Analytics integration.
 * @param {string} gdprPrivacyValue Tell if user has consents to be tracked
 * @returns {Promise<object>} Integrations that we need to use on the track
 */

var getTrackIntegrations = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(gdprPrivacyValue) {
    var isGdprAccepted, marketingCloudVisitorId, _yield$Promise$all, adobeAnalyticsIntegration, restOfIntegrations;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            isGdprAccepted = checkGdprIsAccepted(gdprPrivacyValue);
            marketingCloudVisitorId = null;

            if (!isGdprAccepted) {
              _context.next = 8;
              break;
            }

            ;
            _context.next = 6;
            return Promise.all([getAdobeMCVisitorID()]);

          case 6:
            _yield$Promise$all = _context.sent;
            marketingCloudVisitorId = _yield$Promise$all[0];

          case 8:
            adobeAnalyticsIntegration = marketingCloudVisitorId ? {
              marketingCloudVisitorId: marketingCloudVisitorId
            } : true;
            restOfIntegrations = isGdprAccepted ? {} : INTEGRATIONS_WHEN_NO_CONSENTS; // if we don't have the user consents we remove all the integrations but Adobe Analytics

            return _context.abrupt("return", _extends({}, restOfIntegrations, {
              'Adobe Analytics': adobeAnalyticsIntegration,
              'Amazon Lambda': true
            }));

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function getTrackIntegrations(_x) {
    return _ref.apply(this, arguments);
  };
}();
/**
 * It returns externalIds to add to context
 *
 * @param {Object} param
 * @param {Object} param.context previous context
 * @param {String} param.xandrId xandrId to be included
 * @returns
 */


var getExternalIds = function getExternalIds(_ref2) {
  var context = _ref2.context,
      xandrId = _ref2.xandrId;
  var shouldSendXandrId = getConfig('sendXandrId') !== false;
  var isValidXandrId = xandrId && parseInt(xandrId) !== 0;

  if (!shouldSendXandrId || !isValidXandrId) {
    return {};
  }

  var SEGMENT_COLLECTION = 'users';
  var SEGMENT_ENCODING = 'none';
  var SEGMENT_TYPE = 'xandr_id';
  var externalIds = [].concat((context == null ? void 0 : context.externalIds) || [], [{
    collection: SEGMENT_COLLECTION,
    encoding: SEGMENT_ENCODING,
    id: xandrId,
    type: SEGMENT_TYPE
  }]);
  var uniqueExternalIds = externalIds.filter(function (_ref3, index) {
    var idFilter = _ref3.id,
        typeFilter = _ref3.type;
    return index === externalIds.findIndex(function (_ref4) {
      var idFind = _ref4.id,
          typeFind = _ref4.type;
      return idFilter === idFind && typeFilter === typeFind;
    });
  });
  return {
    externalIds: uniqueExternalIds
  };
};
/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */


export var decorateContextWithNeededData = /*#__PURE__*/function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(context) {
    var gdprPrivacyValue, isGdprAccepted, _yield$Promise$all2, integrations, xandrId;

    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (context === void 0) {
              context = {};
            }

            _context2.next = 3;
            return getGdprPrivacyValue();

          case 3:
            gdprPrivacyValue = _context2.sent;
            isGdprAccepted = checkGdprIsAccepted(gdprPrivacyValue);
            _context2.next = 7;
            return Promise.all([getTrackIntegrations(gdprPrivacyValue), getXandrId()]);

          case 7:
            _yield$Promise$all2 = _context2.sent;
            integrations = _yield$Promise$all2[0];
            xandrId = _yield$Promise$all2[1];
            return _context2.abrupt("return", _extends({}, context, !isGdprAccepted && {
              ip: '0.0.0.0'
            }, getExternalIds({
              context: context,
              xandrId: xandrId
            }), {
              gdpr_privacy: gdprPrivacyValue,
              integrations: _extends({}, context.integrations, integrations)
            }));

          case 11:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function decorateContextWithNeededData(_x2) {
    return _ref5.apply(this, arguments);
  };
}();
/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */

var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  return new Promise(function (resolve) {
    var initTrack = /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
        var newContext, newProperties, newCallback;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                _context4.next = 2;
                return decorateContextWithNeededData(context);

              case 2:
                newContext = _context4.sent;

                /**
                 * @deprecated Now we use `defaultContextProperties` middleware
                 * and put the info on the context object
                 */
                newProperties = _extends({}, getDefaultProperties(), properties);

                newCallback = /*#__PURE__*/function () {
                  var _ref7 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
                    var _yield$Promise$all3,
                        gdprPrivacyValue,
                        _args3 = arguments;

                    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
                      while (1) {
                        switch (_context3.prev = _context3.next) {
                          case 0:
                            if (callback) callback.apply(void 0, _args3); // eslint-disable-line n/no-callback-literal

                            _context3.next = 3;
                            return Promise.all([getGdprPrivacyValue()]);

                          case 3:
                            _yield$Promise$all3 = _context3.sent;
                            gdprPrivacyValue = _yield$Promise$all3[0];

                            if (checkGdprIsAccepted(gdprPrivacyValue)) {
                              resolve.apply(void 0, _args3);
                            } else {
                              resolve();
                            }

                          case 6:
                          case "end":
                            return _context3.stop();
                        }
                      }
                    }, _callee3);
                  }));

                  return function newCallback() {
                    return _ref7.apply(this, arguments);
                  };
                }();

                window.analytics.track(event, newProperties, _extends({}, newContext, {
                  context: {
                    integrations: _extends({}, newContext.integrations)
                  }
                }), newCallback);

              case 6:
              case "end":
                return _context4.stop();
            }
          }
        }, _callee4);
      }));

      return function initTrack() {
        return _ref6.apply(this, arguments);
      };
    }();

    initTrack();
  });
};
/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var identify = function identify(userId, traits, options, callback) {
  return Promise.resolve(window.analytics.identify(userId, traits, options, callback));
};
/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * @param {string} event The name of the event you’re tracking
 * @param {object=} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  // we put a flag on context to know this track is a page
  context.isPageTrack = true; // just call track again but the with the proper context

  return track(event, properties, context, callback);
};
/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */


var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};

export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};
